JHData
================

Various interfaces for interacting with files stored in the cloud

![image](https://img.shields.io/pypi/v/jhdata?style=flat-square)

## Installing

Install the [PyPI Package](https://pypi.org/project/jhdata/):

    pip install jhdata

## Examples

TODO
